# coding: utf-8
import abc


class MQApi(object):
    """Интерфейс для API очереди сообщений"""
    __metaclass__ = abc.ABCMeta

    @abc.abstractmethod
    def get_tasks_cnt(self, queue_name, reserved_tasks_cnt_dict=None):
        """
        Получение кол-ва заданий в очереди.

        Когда воркер включен, то часть заданий он уже забрал из очереди,
        но еще не начал выполнять. Эти задания называются reserved.
        Они уже не в очереди, но они еще не выполняются.
        А с точки зрения балансировщика,
        они еще в очереди, так как не выполняются.
        По идее их можно получить из очереди сообщений и надо делать это в этом
        методе, но RabbitMQ API дает неверные данные по reserved заданиям,
        поэтому есть такой входной параметр,
        чтобы получить их через CeleryApi и передать сюда.

        :param reserved_tasks_cnt_dict: {
            имя воркера: количество зарезервированных заданий
        }
        :param queue_name: имя очереди
        """
        raise NotImplementedError
